==> gc_board_0.08.06.tar.gz: gc_board_0.08.06/install/install_wizard3.php <==
<?php
///////////////////////////////////////////////////////////////////////////
// install_wizard3.php
// gc_board ġ   ° 
// 2005. 5. 6.
///////////////////////////////////////////////////////////////////////////
?>
<html>
<head>
<title>gc_board ġ  - ° ܰ-</title>
<meta http-equiv="Content-Type" content="text/html; charset=euc-kr">
<link href="../include/gc_board.css" rel="stylesheet" type="text/css">
<script language="javascript">
<!--
function move_page(link)
{
	location = link;
}
//-->
</script>
</head>

<body>
<center>
<br>
<strong><font size="4" color="#7777ff">gc_board ġ  - ° ܰ-</font></strong>
<br><br><br>
<?php
// ߸  ˻
$var_err = false;
if (!isset($admin_user) or empty($admin_user))
	$var_err = true;
if (!isset($admin_passwd) or empty($admin_passwd))
	$var_err = true;
if ($var_err)
{
?>
  <strong><font color="red">߸ Դϴ.</font></strong><br><br>
  </center></body></html>
<?php
	exit;
}
?>
  <table width="600" border="0" cellspacing="5" cellpadding="1" class="main">
    <tr bgcolor="#AAAAAA" height="1">
      <td colspan="2"></td>
    </tr>
    <tr> 
      <td width="65%">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<strong>ġ </strong></td>
      <td width="35%" align="center"><strong>/</strong></td>
    </tr>
    <tr bgcolor="#AAAAAA" height="1">
      <td colspan="2"></td>
    </tr>
<?php
///////////////////////////////////////////////////////////////////////////
// DB 
///////////////////////////////////////////////////////////////////////////

$success_ok = "";
$error_code = "";
// DB  ִ  ´.
// 
//   ̸					: con_info[1]
//     ̸		: con_info[2]
//    н			: con_info[3]
// gc_board ġǾ ִ DB̸	: con_info[4]
if (!file_exists("../config/db_info.php"))
	$success_ok = "";
$info_view = file_get_contents("../config/db_info.php");
$con_info = explode(" ", $info_view);

$connect = @mysql_connect($con_info[1], $con_info[2], $con_info[3])
		or $success_ok = "";
@mysql_select_db($con_info[4])
		or $success_ok = "";
$error_code = "DB   ϴ.";
?>
    <tr> 
      <td>Database Server(MySQL ) </td>
      <td align="center"><?=$success_ok?></td>
    </tr>
<?php
///////////////////////////////////////////////////////////////////////////
// Table 
///////////////////////////////////////////////////////////////////////////
if ($success_ok == "")
{

	// Table  ִ  ´.
	if (!file_exists("../config/table_info.gcs"))
	{
		$success_ok = "";
		$error_code = "config/table_info.gcs  ϴ.";
		break;
	}
	$tbl_view = file_get_contents("../config/table_info.gcs");
	$tbl_view = str_replace("\r\n", "\n", $tbl_view);
	$tbl_info = explode("\n\n", $tbl_view);

	for ($i=0; $i<sizeof($tbl_info); $i++)
	{
		if (!mysql_query($tbl_info[$i]))
		{
			$success_ok = "";
			$error_code = mysql_error();
			break;
		}
	}
} // end if (   Ȯ)
?>
    <tr> 
      <td>Table </td>
      <td align="center"><?=$success_ok?></td>
    </tr>
    <tr>
<?php
///////////////////////////////////////////////////////////////////////////
// ⺻  
///////////////////////////////////////////////////////////////////////////
while ($success_ok == "")
{

	// ְ  
	$gc_board_master_query = "insert into gc_member (member_id, passwd"
			.", name, level, signdate) "
			."values('$admin_user', password('$admin_passwd')"
			.", '$admin_user', '1', now())";
	if (!mysql_query($gc_board_master_query))
	{
		$success_ok = "";
		$error_code = mysql_error();
		break;
	}

	// ⺻ admin_menu 
	if (!file_exists("../docs/init_gc_admin_menu.txt"))
	{
		$success_ok = "";
		$error_code = "docs/init_gc_admin_menu.txt  ϴ.";
		break;
	}
	$admin_menu_file = @file("../docs/init_gc_admin_menu.txt");
	for ($i=0; $i<sizeof($admin_menu_file); $i++)
	{
		$insert_query_tail = "";
		$admin_menu_info = explode("\t", $admin_menu_file[$i]);
		for ($j=0; $j<sizeof($admin_menu_info); $j++)
			$insert_query_tail .= "'".$admin_menu_info[$j]."' ,";
		$insert_query_tail = substr($insert_query_tail, 0
					, strlen($insert_query_tail)-2);
		$insert_query = "insert into gc_admin_menu values(".$insert_query_tail.")";
		if (!mysql_query($insert_query))
		{
			$success_ok = "";
			$error_code = mysql_error();
			break;
		}
	}
	if ($success_ok == "")
		break;

	// ⺻ basic_config 
	if (!file_exists("../docs/init_gc_basic_config.txt"))
	{
		$success_ok = "";
		$error_code = "docs/init_gc_basic_config.txt  ϴ.";
		break;
	}
	$basic_config_file = @file("../docs/init_gc_basic_config.txt");
	for ($i=0; $i<sizeof($basic_config_file); $i++)
	{
		$insert_query_tail = "";
		$basic_config_info = explode("\t", $basic_config_file[$i]);
		for ($j=0; $j<sizeof($basic_config_info); $j++)
			$insert_query_tail .= "'".$basic_config_info[$j]."' ,";
		$insert_query_tail = substr($insert_query_tail, 0
					, strlen($insert_query_tail)-2);
		$insert_query = "insert into gc_basic_config values(".$insert_query_tail.")";
		if (!mysql_query($insert_query))
		{
			$success_ok = "";
			$error_code = mysql_error();
			break;
		}
	}
	if ($success_ok == "")
		break;

	// ⺻ level 
	if (!file_exists("../docs/init_gc_level.txt"))
	{
		$success_ok = "";
		$error_code = "docs/init_gc_level.txt";
		break;
	}
	$level_file = @file("../docs/init_gc_level.txt");
	for ($i=0; $i<sizeof($level_file); $i++)
	{
		$insert_query_tail = "";
		$level_info = explode("\t", $level_file[$i]);
		for ($j=0; $j<sizeof($level_info); $j++)
			$insert_query_tail .= "'".$level_info[$j]."' ,";
		$insert_query_tail = substr($insert_query_tail, 0
					, strlen($insert_query_tail)-2);
		$insert_query = "insert into gc_level values(".$insert_query_tail.")";
		if (!mysql_query($insert_query))
		{
			$success_ok = "";
			$error_code = mysql_error();
			break;
		}
	}
	if ($success_ok == "")
		break;

	// ⺻ member_entrance 
	if (!file_exists("../docs/init_gc_member_entrance.txt"))
	{
		$success_ok = "";
		$error_code = "docs/init_gc_member_entrance.txt  ϴ.";
		break;
	}
	$member_entrance_file = @file("../docs/init_gc_member_entrance.txt");
	for ($i=0; $i<sizeof($member_entrance_file); $i++)
	{
		$insert_query_tail = "";
		$member_entrance_info = explode("\t", $member_entrance_file[$i]);
		for ($j=0; $j<sizeof($member_entrance_info); $j++)
			$insert_query_tail .= "'".$member_entrance_info[$j]."' ,";
		$insert_query_tail = substr($insert_query_tail, 0
					, strlen($insert_query_tail)-2);
		$insert_query = "insert into gc_member_entrance values(".$insert_query_tail.")";
		if (!mysql_query($insert_query))
		{
			$success_ok = "";
			$error_code = mysql_error();
			break;
		}
	}
	if ($success_ok == "")
		break;

	// ⺻ zipcode(ȣ) 
	if (!file_exists("../docs/zipcode031019t6.txt"))
	{
		$success_ok = "";
		$error_code = "docs/zipcode031019t6.txt  ϴ.";
		break;
	}
	$zipcode_file = @file("../docs/zipcode031019t6.txt");
	for ($i=0; $i<sizeof($zipcode_file); $i++)
	{
		$insert_query_tail = "";
		$zipcode_info = explode("\t", $zipcode_file[$i]);
		for ($j=0; $j<sizeof($zipcode_info); $j++)
			$insert_query_tail .= "'".$zipcode_info[$j]."' ,";
		$insert_query_tail = substr($insert_query_tail, 0
					, strlen($insert_query_tail)-2);
		$insert_query = "insert into gc_zipcode values(".$insert_query_tail.")";
		if (!mysql_query($insert_query))
		{
			$success_ok = "";
			$error_code = mysql_error();
			break;
		}
	}
	if ($success_ok == "")
		break;

	// ⺻ Խ 
	mysql_close();
	$no_session = true; //   
	include "../include/gc_manage_lib.php";
	add_board("default", "⺻Խ", "../board/skin/default", "", 0
			, "../board/skin/default/header.htm", "../board/skin/default/footer.htm");
	break; // Ƿ .

} // end while (   Ȯ)
?>
      <td>⺻  </td>
      <td align="center"><?=$success_ok?></td>
    </tr>
<?php
if ($success_ok == "")
{
	//  ó κ 
	include "../install/install_error.php";
?>
    <tr>
      <td> </td>
      <td><?=$error_code?></td>
    </tr>
<?php
}
?>
    <tr bgcolor="#AAAAAA" height="1">
      <td colspan="2"></td>
    </tr>
<?php
if ($success_ok == "")
{
?>
    <tr align="center"> 
      <td colspan="2"><form name="form1" method="post" action="">
          <input name="move_admin" type="button" class="submitform" id="move_admin" value="  ̵" onclick="javascript:move_page('../admin/admin_login.php');">
        </form></td>
    </tr>
<?php
}
else
{
?>
    <tr>
      <td colspan="2" align="center"><a href="../install/install_wizard1.php">ٽ ġϱ</a></td>
    </tr>
<?
}
?>
  </table>
</center>
</body>
</html>

==> gc_board_0.09.00.tar.gz: gc_board_0.09.00/install/install_wizard3.php <==
<?php
///////////////////////////////////////////////////////////////////////////
// install_wizard3.php
// gc_board ġ   ° 
// 2005. 7. 20.
///////////////////////////////////////////////////////////////////////////
?>
<html>
<head>
<title>gc_board ġ  - ° ܰ-</title>
<meta http-equiv="Content-Type" content="text/html; charset=euc-kr">
<link href="../include/gc_board.css" rel="stylesheet" type="text/css">
<script language="javascript">
<!--
function move_page(link)
{
	location = link;
}
//-->
</script>
</head>

<body>
<center>
<br>
<strong><font size="4" color="#7777ff">gc_board ġ  - ° ܰ-</font></strong>
<br><br><br>
<?php
//  ð  ε 
set_time_limit(0);
// ߸  ˻
$var_err = false;
if (!isset($admin_user) or empty($admin_user))
	$var_err = true;
if (!isset($admin_passwd) or empty($admin_passwd))
	$var_err = true;
if ($var_err)
{
?>
  <strong><font color="red">߸ Դϴ.</font></strong><br><br>
  </center></body></html>
<?php
	exit;
}
?>
  <table width="600" border="0" cellspacing="5" cellpadding="1" class="main">
    <tr>
      <td bgcolor="#AAAAAA" height="1" colspan="2"></td>
    </tr>
    <tr> 
      <td width="65%">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<strong>ġ </strong></td>
      <td width="35%" align="center"><strong>/</strong></td>
    </tr>
    <tr>
      <td bgcolor="#AAAAAA" height="1" colspan="2"></td>
    </tr>
<?php
///////////////////////////////////////////////////////////////////////////
// DB 
///////////////////////////////////////////////////////////////////////////

$success_ok = "";
$error_code = "";
// DB  ִ  ´.
// 
//   ̸					: con_info[1]
//     ̸		: con_info[2]
//    н			: con_info[3]
// gc_board ġǾ ִ DB̸	: con_info[4]
if (!@file_exists("../config/db_info.php"))
	$success_ok = "";
$info_view = file_get_contents("../config/db_info.php");
$con_info = explode(" ", $info_view);

$connect = @mysql_connect($con_info[1], $con_info[2], $con_info[3])
		or $success_ok = "";
@mysql_select_db($con_info[4])
		or $success_ok = "";
$error_code = "DB   ϴ.";
?>
    <tr> 
      <td>Database Server(MySQL ) </td>
      <td align="center"><?=$success_ok?></td>
    </tr>
<?php
///////////////////////////////////////////////////////////////////////////
// Table 
///////////////////////////////////////////////////////////////////////////
if ($success_ok == "")
{

	// Table  ִ  ´.
	if (!@file_exists("../config/table_info.gcs"))
	{
		$success_ok = "";
		$error_code = "config/table_info.gcs  ϴ.";
		break;
	}
	$tbl_view = file_get_contents("../config/table_info.gcs");
	$tbl_view = str_replace("\r\n", "\n", $tbl_view);
	$tbl_info = explode("\n\n", $tbl_view);

	for ($i=0; $i<sizeof($tbl_info); $i++)
	{
		if (!@mysql_query($tbl_info[$i]))
		{
			$success_ok = "";
			$error_code = mysql_error();
			break;
		}
	}
} // end if (   Ȯ)
?>
    <tr> 
      <td>Table </td>
      <td align="center"><?=$success_ok?></td>
    </tr>
    <tr>
<?php
///////////////////////////////////////////////////////////////////////////
// ⺻  
///////////////////////////////////////////////////////////////////////////
while ($success_ok == "")
{

	// ְ  
	$gc_board_master_query = "insert into gc_member (member_id, passwd"
			.", name, level, signdate) "
			."values('$admin_user', password('$admin_passwd')"
			.", '$admin_user', '1', now())";
	if (!@mysql_query($gc_board_master_query))
	{
		$success_ok = "";
		$error_code = mysql_error();
		break;
	}

	// ⺻ admin_menu 
	if (!@file_exists("../docs/init_gc_admin_menu.txt"))
	{
		$success_ok = "";
		$error_code = "docs/init_gc_admin_menu.txt  ϴ.";
		break;
	}
	$admin_menu_file = @file("../docs/init_gc_admin_menu.txt");
	for ($i=0; $i<sizeof($admin_menu_file); $i++)
	{
		$insert_query_tail = "";
		$admin_menu_info = explode("\t", $admin_menu_file[$i]);
		for ($j=0; $j<sizeof($admin_menu_info); $j++)
			$insert_query_tail .= "'".$admin_menu_info[$j]."' ,";
		$insert_query_tail = substr($insert_query_tail, 0
					, strlen($insert_query_tail)-2);
		$insert_query = "insert into gc_admin_menu values(".$insert_query_tail.")";
		if (!@mysql_query($insert_query))
		{
			$success_ok = "";
			$error_code = mysql_error();
			break;
		}
	}
	if ($success_ok == "")
		break;

	// ⺻ basic_config 
	if (!@file_exists("../docs/init_gc_basic_config.txt"))
	{
		$success_ok = "";
		$error_code = "docs/init_gc_basic_config.txt  ϴ.";
		break;
	}
	$basic_config_file = @file("../docs/init_gc_basic_config.txt");
	for ($i=0; $i<sizeof($basic_config_file); $i++)
	{
		$insert_query_tail = "";
		$basic_config_info = explode("\t", $basic_config_file[$i]);
		for ($j=0; $j<sizeof($basic_config_info); $j++)
			$insert_query_tail .= "'".$basic_config_info[$j]."' ,";
		$insert_query_tail = substr($insert_query_tail, 0
					, strlen($insert_query_tail)-2);
		$insert_query = "insert into gc_basic_config values(".$insert_query_tail.")";
		if (!@mysql_query($insert_query))
		{
			$success_ok = "";
			$error_code = mysql_error();
			break;
		}
	}
	if ($success_ok == "")
		break;

	// ⺻ level 
	if (!@file_exists("../docs/init_gc_level.txt"))
	{
		$success_ok = "";
		$error_code = "docs/init_gc_level.txt";
		break;
	}
	$level_file = @file("../docs/init_gc_level.txt");
	for ($i=0; $i<sizeof($level_file); $i++)
	{
		$insert_query_tail = "";
		$level_info = explode("\t", $level_file[$i]);
		for ($j=0; $j<sizeof($level_info); $j++)
			$insert_query_tail .= "'".$level_info[$j]."' ,";
		$insert_query_tail = substr($insert_query_tail, 0
					, strlen($insert_query_tail)-2);
		$insert_query = "insert into gc_level values(".$insert_query_tail.")";
		if (!@mysql_query($insert_query))
		{
			$success_ok = "";
			$error_code = mysql_error();
			break;
		}
	}
	if ($success_ok == "")
		break;

	// ⺻ member_entrance 
	if (!@file_exists("../docs/init_gc_member_entrance.txt"))
	{
		$success_ok = "";
		$error_code = "docs/init_gc_member_entrance.txt  ϴ.";
		break;
	}
	$member_entrance_file = @file("../docs/init_gc_member_entrance.txt");
	for ($i=0; $i<sizeof($member_entrance_file); $i++)
	{
		$insert_query_tail = "";
		$member_entrance_info = explode("\t", $member_entrance_file[$i]);
		for ($j=0; $j<sizeof($member_entrance_info); $j++)
			$insert_query_tail .= "'".$member_entrance_info[$j]."' ,";
		$insert_query_tail = substr($insert_query_tail, 0
					, strlen($insert_query_tail)-2);
		$insert_query = "insert into gc_member_entrance values(".$insert_query_tail.")";
		if (!@mysql_query($insert_query))
		{
			$success_ok = "";
			$error_code = mysql_error();
			break;
		}
	}
	if ($success_ok == "")
		break;

	// ⺻ zipcode(ȣ) 
	if (!@file_exists("../config/ZIPCODE6.SQL"))
	{
		$success_ok = "";
		$error_code = "config/ZIPCODE6.SQL  ϴ.";
		break;
	}
	$zipcode_file = file_get_contents("../config/ZIPCODE6.SQL");
	$zipcode_file = str_replace("\r\n", "\n", $zipcode_file);
	$zipcode_sql = explode("\n\n", $zipcode_file);

	@mysql_query($zipcode_sql[1]);		//  zipcode ̺ 
	if (!@mysql_query($zipcode_sql[2]))	// ο zipcode ̺ 
	{
		$success_ok = "";
		$error_code = mysql_error();
		break;
	}
	// ȣ Է
	$zipcode_insert_sql = explode("\n", $zipcode_sql[4]);
	$cnt_zipcode = count($zipcode_insert_sql);
	for ($i=0; $i<$cnt_zipcode; $i++)
	{
		if (!empty($zipcode_insert_sql[$i]) and !@mysql_query($zipcode_insert_sql[$i]))
		{
			$success_ok = "";
			$error_code = mysql_error();
			break;
		}
	}
	if ($success_ok == "")
		break;

	// ⺻ Խ 

	// Խ  
	$info_query = "insert into gc_board_info (tblname, tbltitle, skinname"
		.", guestbook_ok, lattice_ok, lattice_cols, lattice_rows"
		.", top_file, bottom_file, back_file, top_text"
		.", row_per_page, pagenum_per_view, reply_ok, comment_ok"
		.", upload_ok, upload_size, write_auth, read_auth"
		.", comment_auth, list_auth, delete_auth) "
		."values('default', '⺻Խ', '../board/skin/simple_gray'"
		.", '0', '0', '1', '15'"
		.", '', '', '', ''"
		.", '15', '10', '1', '1'"
		.", '0', '2M', '11', '11'"
		.", '11', '11', '6')";
	if (!@mysql_query($info_query))
	{
		$success_ok = "";
		$error_code = mysql_error();
		break;
	}

	// Խ ̺ 
	$main_query =
		 "create table gc_board_main_default ("
		."maintext_id int unsigned primary key auto_increment,"	// Խù ID
		."fsort_id int unsigned not null,"						// ù °   
		."ssort_id varchar(8) not null,"						//  °()   
		."member_id varchar(8),"								// α      ۼ
		."name varchar(255),"									// ۼ ̸
		."passwd char(41),"										//  н
		."subject varchar(60) not null,"						//  
		."email varchar(60),"									//  ۼ email
		."homepage varchar(255),"								//  ۼ homepage
		."content text,"										//  
		."signdate date not null,"								//  ۼ ð
		."view_file_name varchar(255),"							// ε ϸ
		."save_file_name varchar(255),"							// ε    ̸
		."view_count int unsigned not null default 0,"			// ȸ
		."recommend int unsigned not null default 0,"			// õ
		."notice_ok int(1) not null default 0,"					//   
		."text_type char(4) not null default 'text')";			//    ( html / text )
	if (!@mysql_query($main_query))
	{
		$success_ok = "";
		$error_code = mysql_error();
		break;
	}

	// comment ̺ 
	$comment_query =
		 "create table gc_board_comment_default ("
		."comment_id int unsigned primary key auto_increment,"	// comment ID
		."maintext_id int unsigned not null,"					//   ID
		."member_id varchar(8),"								// α      ۼ
		."name varchar(255) not null,"							// ۼ ̸
		."comment text not null,"								// comment 
		."signdate date not null)";								// comment ۼ ð
	if (!@mysql_query($comment_query))
	{
		$success_ok = "";
		$error_code = mysql_error();
		break;
	}

	// 丮 
	if (!file_exists("../board/files/default") and !@mkdir("../board/files/default"))
	{
		$success_ok = "";
		$error_code = "../board/files/default 丮   ϴ. "
				."../board/files   ֽñ ٶϴ.";
	}
	
	break; // Ƿ .

} // end while (   Ȯ)
?>
      <td>⺻  </td>
      <td align="center"><?=$success_ok?></td>
    </tr>
<?php
if ($success_ok == "")
{
	//  ó κ 
	include "../install/install_error.php";
?>
    <tr>
      <td> </td>
      <td><?=$error_code?></td>
    </tr>
<?php
}
?>
    <tr>
      <td bgcolor="#AAAAAA" height="1" colspan="2"></td>
    </tr>
<?php
if ($success_ok == "")
{
?>
    <tr align="center"> 
      <td colspan="2"><form name="form1" method="post" action="">
          <input name="move_admin" type="button" class="submitform" id="move_admin" value="  ̵" onclick="javascript:move_page('../admin/admin_login.php');">
        </form></td>
    </tr>
<?php
}
else
{
?>
    <tr>
      <td colspan="2" align="center"><a href="../install/install_wizard1.php">ٽ ġϱ</a></td>
    </tr>
<?
}
?>
  </table>
</center>
</body>
</html>
